Search.setIndex({envversion:42,terms:{origin:1,all:[0,1],code:[0,1],help:0,routin:0,thi:[0,1],freeze_exec_fail:0,sampl:[0,1],through:0,follow:1,reput:0,digest:0,staff:0,xml:[0,1],damag:1,onli:0,procur:1,monitor:0,fit:1,polici:[0,1],fix:[0,1],configur:0,send:0,should:1,jan:1,tort:1,add:[0,1],busi:1,present:0,persist:[0,1],aris:1,main:0,local:0,easier:[0,1],bin:0,offici:[0,1],good:1,format:0,python:[0,1],express:1,pypi:0,luka:1,mechan:0,condit:[0,1],interrupt:1,liabl:1,requir:0,python2:0,choic:0,document:1,like:[0,1],organ:0,creativ:1,list:1,authent:0,"public":0,easili:[0,1],either:[0,1],contain:1,refer:1,attributeerror:1,manag:[0,1],view:1,pleas:0,conform:0,domain:0,set:[0,1],ongo:0,direct:1,intern:1,design:[0,1],expect:0,pass:0,fail:0,close:1,indirect:1,todo:0,event:1,transport:0,gmail:0,even:1,project:[0,1],servic:1,defin:0,profit:1,databas:[0,1],feedback:0,exim:0,current:0,substitut:1,conduct:0,"import":[0,1],duplic:1,reproduc:1,importdmarcreport:[0,1],attribut:1,altern:[0,1],dmarc_report:0,privat:0,run:[0,1],migrat:[0,1],gener:0,prior:0,style:[0,1],here:0,disclaim:1,met:1,reason:0,base:0,modif:1,theori:1,although:0,releas:0,path:0,interpret:1,stage:0,protect:0,easi:0,befor:1,howev:1,incident:1,contract:1,thing:[0,1],perhap:0,organis:0,prefetch:1,ltd:1,retain:1,implement:0,assign:1,chanc:0,user:0,comment:0,softwar:1,getroot:1,directli:0,question:0,app:[0,1],impli:1,ahick:0,warranti:1,email:[0,1],right:[0,1],exemplari:1,org:1,contributor:1,stabl:0,installed_app:[0,1],miss:1,your:[0,1],linjan:1,size:0,liabil:1,sourc:1,from:0,creat:[0,1],wai:[0,1],commun:0,trans_dmarcreport:0,visit:1,transform:0,messag:0,traction:0,strict:1,includ:[0,1],save:1,pipe:[0,1],instal:[0,1],quickli:[0,1],zip:[0,1],desir:0,option:0,form:1,offer:0,brand:0,under:1,about:0,notic:1,provid:1,gain:0,particular:1,"true":0,conclus:1,must:1,creativecommon:1,made:0,possibl:1,whether:1,neglig:1,couldn:0,redistribut:1,structur:0,aim:0,record:1,limit:1,can:[0,1],abov:1,error:1,those:1,otherwis:1,purpos:1,materi:1,merchant:1,bootstrap:[0,1],evalu:0,give:0,smtp:0,ani:1,accept:0,repres:1,download:0,tag:1,file:[0,1],reserv:1,improv:1,optimis:1,return_fail_output:0,issu:0,built:0,author:[0,1],local_part:0,make:[0,1],contact:0,member:0,binari:1,other:1,take:0,advis:1,test:1,you:[0,1],out:1,phish:0,websit:0,copi:1,http:1,allow:1,combat:0,shall:1,permit:1,driver:0,supress:1,consequenti:1,"p\u00fchringer":1,fairli:0,beta:0,thank:1,amongst:0,distribut:1,router:0,usr:0,data:[0,1],model:[0,1],googl:0,special:1,url:0,secur:0,object:[0,1],element:1,caus:1,more:0,common:1,without:1,command:0,freebsd:1,choos:[0,1],dmarcreport:0,loss:1,self:1},objtypes:{},objnames:{},filenames:["README","index"],titles:["Django DMARC","Django DMARC"],objects:{},titleterms:{depend:0,log:1,copyright:1,usag:0,support:0,descript:0,django:[0,1],content:1,start:[0,1],version:1,quick:[0,1],report:0,resourc:0,chang:1,licens:1,dmarc:[0,1]}})